@@ -123,8 +123,7 @@ class EssClient(AbstractClient):
 
     def CreateDocument(self, request):
         """创建签署流程电子文档
-        适用场景：见创建签署流程接口。
-
+        适用场景：见创建签署流程接口。x0b
         注：该接口需要给对应的流程指定一个模板id，并且填充该模板中需要补充的信息。是“发起流程”接口的前置接口。
 
         :param request: Request instance for CreateDocument.
@@ -252,7 +251,7 @@ class EssClient(AbstractClient):
     def CreateFlowReminds(self, request):
         """指定需要批量催办的签署流程Id，批量催办合同，最多100个; 接口失败后返回错误信息
         注意:
-        该接口需要开白后使用
+        该接口不可直接调用，需要联系运营开通后方可调用。
 
         :param request: Request instance for CreateFlowReminds.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowRemindsRequest`
